@@ -4,13 +4,16 @@
 
     from nitpick.generic import *
 """
+
+from __future__ import annotations
+
 import abc
 import json
 import re
 import shlex
-from functools import lru_cache, partial
+from functools import partial
 from pathlib import Path
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, TypeVar, cast
 
 import dictdiffer
 import jmespath
@@ -19,13 +22,18 @@ import tomlkit
 from attr import define  # type: ignore[attr-defined]
 from autorepr import autorepr
 from flatten_dict import flatten, unflatten
-from jmespath.parser import ParsedResult
 from ruamel.yaml import YAML, RoundTripRepresenter, StringIO
 from sortedcontainers import SortedDict
 from tomlkit import items
 
-from nitpick.config import SpecialConfig
-from nitpick.typedefs import ElementData, JsonDict, ListOrCommentedSeq, PathOrStr, YamlObject, YamlValue
+if TYPE_CHECKING:
+    from jmespath.parser import ParsedResult
+
+    from nitpick.config import SpecialConfig
+    from nitpick.typedefs import ElementData, JsonDict, ListOrCommentedSeq, PathOrStr, YamlObject, YamlValue
+
+# Generic type for classes that inherit from BaseDoc
+TBaseDoc = TypeVar("TBaseDoc", bound="BaseDoc")
 
 SINGLE_QUOTE = "'"
 DOUBLE_QUOTE = '"'
@@ -39,13 +47,13 @@ SEPARATOR_SPACE = " "
 # to avoid collision with existing key values (e.g. the default SEPARATOR_DOT separator "." can be part of a TOML key).
 SEPARATOR_FLATTEN = "$#@"
 
-#: Special unique separator for :py:meth:`nitpick.generic.quoted_split()`.
+#: Special unique separator for :py:meth:`nitpick.blender.quoted_split()`.
 SEPARATOR_QUOTED_SPLIT = "#$@"
 
 
 def compare_lists_with_dictdiffer(
-    actual: Union[List, Dict], expected: Union[List, Dict], *, return_list: bool = True
-) -> Union[List, Dict]:
+    actual: list | dict, expected: list | dict, *, return_list: bool = True
+) -> list | dict:
     """Compare two lists using dictdiffer."""
     additions_and_changes = [change for change in dictdiffer.diff(actual, expected) if change[0] != "remove"]
     if not additions_and_changes:
@@ -61,8 +69,10 @@ def compare_lists_with_dictdiffer(
     return changed_dict
 
 
-def search_json(json_data: ElementData, jmespath_expression: Union[ParsedResult, str], default: Any = None) -> Any:
-    """Search a dictionary or list using a JMESPath expression. Return a default value if not found.
+def search_json(json_data: ElementData, jmespath_expression: ParsedResult | str, default: Any | None = None) -> Any:
+    """Search a dictionary or list using a JMESPath expression.
+
+    Return a default value if not found.
 
     >>> data = {"root": {"app": [1, 2], "test": "something"}}
     >>> search_json(data, "root.app", None)
@@ -102,7 +112,7 @@ class ElementDetail:  # pylint: disable=too-few-public-methods
     """Detailed information about an element of a list."""
 
     data: ElementData
-    key: Union[str, List[str]]
+    key: str | list[str]
     index: int
     scalar: bool
     compact: str
@@ -110,10 +120,10 @@ class ElementDetail:  # pylint: disable=too-few-public-methods
     @property
     def cast_to_dict(self) -> JsonDict:
         """Data cast to dict, for mypy."""
-        return cast(JsonDict, self.data)
+        return cast("JsonDict", self.data)
 
     @classmethod
-    def from_data(cls, index: int, data: ElementData, jmes_key: str) -> "ElementDetail":
+    def from_data(cls, index: int, data: ElementData, jmes_key: str) -> ElementDetail:
         """Create an element detail from dict data."""
         if isinstance(data, (list, dict)):
             scalar = False
@@ -124,7 +134,7 @@ class ElementDetail:  # pylint: disable=too-few-public-methods
         else:
             scalar = True
             key = compact = str(data)
-        return ElementDetail(data=data, key=key, index=index, scalar=scalar, compact=compact)  # type: ignore[call-arg]
+        return ElementDetail(data=data, key=key, index=index, scalar=scalar, compact=compact)
 
 
 @define
@@ -132,24 +142,23 @@ class ListDetail:  # pylint: disable=too-few-public-methods
     """Detailed info about a list."""
 
     data: ListOrCommentedSeq
-    elements: List[ElementDetail]
+    elements: list[ElementDetail]
 
     @classmethod
-    def from_data(cls, data: ListOrCommentedSeq, jmes_key: str) -> "ListDetail":
+    def from_data(cls, data: ListOrCommentedSeq, jmes_key: str) -> ListDetail:
         """Create a list detail from list data."""
-        return ListDetail(  # type: ignore[call-arg]
+        return ListDetail(
             data=data, elements=[ElementDetail.from_data(index, data, jmes_key) for index, data in enumerate(data)]
         )
 
-    def find_by_key(self, desired: ElementDetail) -> Optional[ElementDetail]:
+    def find_by_key(self, desired: ElementDetail) -> ElementDetail | None:
         """Find an element by key."""
         for actual in self.elements:
             if isinstance(desired.key, list):
                 if set(desired.key).issubset(set(actual.key)):
                     return actual
-            else:
-                if desired.key == actual.key:
-                    return actual
+            elif desired.key == actual.key:
+                return actual
         return None
 
 
@@ -160,7 +169,7 @@ def set_key_if_not_empty(dict_: JsonDict, key: str, value: Any) -> None:
     dict_[key] = value
 
 
-def quoted_split(string_: str, separator=SEPARATOR_DOT) -> List[str]:
+def quoted_split(string_: str, separator=SEPARATOR_DOT) -> list[str]:
     """Split a string by a separator, but considering quoted parts (single or double quotes).
 
     >>> quoted_split("my.key.without.quotes")
@@ -186,7 +195,7 @@ def quoted_split(string_: str, separator=SEPARATOR_DOT) -> List[str]:
     )
 
     def remove_quotes(match):
-        return match.group(0).strip("".join([SINGLE_QUOTE, DOUBLE_QUOTE])).replace(separator, SEPARATOR_QUOTED_SPLIT)
+        return match.group(0).strip(f"{SINGLE_QUOTE}{DOUBLE_QUOTE}").replace(separator, SEPARATOR_QUOTED_SPLIT)
 
     return [
         part.replace(SEPARATOR_QUOTED_SPLIT, separator)
@@ -204,9 +213,12 @@ def quote_if_dotted(key: str) -> str:
 
 
 def quote_reducer(separator: str) -> Callable:
-    """Reducer used to unflatten dicts. Quote keys when they have dots."""
+    """Reducer used to unflatten dicts.
 
-    def _inner_quote_reducer(key1: Optional[str], key2: str) -> str:
+    Quote keys when they have dots.
+    """
+
+    def _inner_quote_reducer(key1: str | None, key2: str) -> str:
         if key1 is None:
             return quote_if_dotted(key2)
         return f"{key1}{separator}{quote_if_dotted(key2)}"
@@ -214,7 +226,7 @@ def quote_reducer(separator: str) -> Callable:
     return _inner_quote_reducer
 
 
-def quotes_splitter(flat_key: str) -> Tuple[str, ...]:
+def quotes_splitter(flat_key: str) -> tuple[str, ...]:
     """Split keys keeping quoted strings together."""
     return tuple(
         piece.replace(SEPARATOR_SPACE, SEPARATOR_DOT) if SEPARATOR_SPACE in piece else piece
@@ -236,13 +248,34 @@ def custom_reducer(separator: str) -> Callable:
 def custom_splitter(separator: str) -> Callable:
     """Custom splitter for :py:meth:`flatten_dict.flatten_dict.unflatten()` accepting a separator."""
 
-    def _inner_custom_splitter(flat_key) -> Tuple[str, ...]:
-        keys = tuple(flat_key.split(separator))
-        return keys
+    def _inner_custom_splitter(flat_key) -> tuple[str, ...]:
+        """Return a tuple of keys split by the separator."""
+        return tuple(flat_key.split(separator))
 
     return _inner_custom_splitter
 
 
+# TODO: refactor: use only tomlkit and remove uiri/toml
+#  - tomlkit preserves comments
+#  - uiri/toml looks abandoned https://github.com/uiri/toml/issues/361
+#  Code to be used with tomlkit when merging styles
+# merged_dict = unflatten(self._merged_styles, toml_style_splitter)
+# def toml_style_splitter(flat_key: str) -> Tuple[str, ...]:
+#     """Splitter for TOML style files, in an attempt to remove empty TOML tables."""
+#     original = flat_key.split(SEPARATOR_FLATTEN)
+#     quoted = [quote_if_dotted(k) for k in original]
+#
+#     first = quoted.pop(0)
+#     last = quoted.pop() if quoted else None
+#
+#     grouped = [first]
+#     if quoted:
+#         grouped.append(SEPARATOR_DOT.join(quoted))
+#     if last:
+#         grouped.append(last)
+#     return tuple(grouped)
+
+
 def flatten_quotes(dict_: JsonDict, separator=SEPARATOR_DOT) -> JsonDict:
     """Flatten a dict keeping quotes in keys."""
     dict_with_quoted_keys = flatten(dict_, reducer=quote_reducer(separator))
@@ -264,7 +297,7 @@ unflatten_quotes = partial(unflatten, splitter=quotes_splitter)
 class Comparison:
     """A comparison between two dictionaries, computing missing items and differences."""
 
-    def __init__(self, actual: "BaseDoc", expected: JsonDict, special_config: SpecialConfig) -> None:
+    def __init__(self, actual: TBaseDoc, expected: JsonDict, special_config: SpecialConfig) -> None:
         self.flat_actual = flatten_quotes(actual.as_object)
         self.flat_expected = flatten_quotes(expected)
 
@@ -277,32 +310,32 @@ class Comparison:
         self.special_config = special_config
 
     @property
-    def missing(self) -> Optional["BaseDoc"]:
+    def missing(self) -> TBaseDoc | None:
         """Missing data."""
         if not self.missing_dict:
             return None
-        return self.doc_class(obj=(unflatten_quotes(self.missing_dict)))
+        return self.doc_class(obj=(unflatten_quotes(self.missing_dict)))  # type: ignore[return-value]
 
     @property
-    def diff(self) -> Optional["BaseDoc"]:
+    def diff(self) -> TBaseDoc | None:
         """Different data."""
         if not self.diff_dict:
             return None
-        return self.doc_class(obj=(unflatten_quotes(self.diff_dict)))
+        return self.doc_class(obj=(unflatten_quotes(self.diff_dict)))  # type: ignore[return-value]
 
     @property
-    def replace(self) -> Optional["BaseDoc"]:
+    def replace(self) -> TBaseDoc | None:
         """Data to be replaced."""
         if not self.replace_dict:
             return None
-        return self.doc_class(obj=unflatten_quotes(self.replace_dict))
+        return self.doc_class(obj=unflatten_quotes(self.replace_dict))  # type: ignore[return-value]
 
     @property
     def has_changes(self) -> bool:
         """Return True is there is a difference or something missing."""
         return bool(self.missing or self.diff or self.replace)
 
-    def __call__(self) -> "Comparison":
+    def __call__(self) -> Comparison:
         """Compare two flattened dictionaries and compute missing and different items."""
         if self.flat_expected.items() <= self.flat_actual.items():
             return self
@@ -360,7 +393,7 @@ class Comparison:
                 actual_element.cast_to_dict, expected_element.cast_to_dict, return_list=False
             )
             if diff:
-                new_block = cast(JsonDict, actual_element.data).copy()
+                new_block = cast("JsonDict", actual_element.data).copy()
                 new_block.update(diff)
                 display.append(new_block)
                 replace[actual_element.index] = new_block
@@ -384,9 +417,9 @@ class Comparison:
         expected_nested = search_json(expected_element.data, jmes_nested, [{}])
         diff_nested = compare_lists_with_dictdiffer(actual_nested, expected_nested, return_list=True)
         if diff_nested:
-            actual_data = cast(JsonDict, actual_element.data)
-            expected_data = cast(JsonDict, expected_element.data)
-            # TODO: set value deep down the tree (try dpath-python). parent_key = 'regions[].cities[].people'
+            actual_data = cast("JsonDict", actual_element.data)
+            expected_data = cast("JsonDict", expected_element.data)
+            # TODO: fix: set value deep down the tree (try dpath-python). parent_key = 'regions[].cities[].people'
             expected_data[parent_key] = diff_nested
 
             new_nested_block = actual_data.copy()
@@ -407,12 +440,14 @@ class BaseDoc(metaclass=abc.ABCMeta):
 
     __repr__ = autorepr(["path"])
 
-    def __init__(self, *, path: PathOrStr = None, string: str = None, obj: JsonDict = None) -> None:
+    def __init__(
+        self, *, path: PathOrStr | None = None, string: str | None = None, obj: JsonDict | None = None
+    ) -> None:
         self.path = path
         self._string = string
         self._object = obj
 
-        self._reformatted: Optional[str] = None
+        self._reformatted: str | None = None
 
     @abc.abstractmethod
     def load(self) -> bool:
@@ -424,7 +459,7 @@ class BaseDoc(metaclass=abc.ABCMeta):
         return self._string or ""
 
     @property
-    def as_object(self) -> Dict:
+    def as_object(self) -> dict:
         """String content converted to a Python object (dict, YAML object instance, etc.)."""
         if self._object is None:
             self.load()
@@ -455,32 +490,63 @@ class InlineTableTomlDecoder(toml.TomlDecoder):  # type: ignore[name-defined]
 class TomlDoc(BaseDoc):
     """TOML configuration format."""
 
+    # TODO: refactor: use only tomlkit and remove uiri/toml
+    #   remove __init__() completely
     def __init__(
         self,
         *,
-        path: PathOrStr = None,
-        string: str = None,
-        obj: JsonDict = None,
+        path: PathOrStr | None = None,
+        string: str | None = None,
+        obj: JsonDict | None = None,
         use_tomlkit=False,
     ) -> None:
         super().__init__(path=path, string=string, obj=obj)
         self.use_tomlkit = use_tomlkit
 
-    @lru_cache()
     def load(self) -> bool:
         """Load a TOML file by its path, a string or a dict."""
         if self.path is not None:
             self._string = Path(self.path).read_text(encoding="UTF-8")
         if self._string is not None:
-            # TODO: I tried to replace toml by tomlkit, but lots of tests break.
+            # TODO: refactor: use only tomlkit and remove uiri/toml
+            #  I tried to replace toml by tomlkit, but lots of tests break.
             if self.use_tomlkit:
+                # TODO: refactor: use only tomlkit and remove uiri/toml
+                #  Removing empty tables on loads() didn't work.
+                #  The empty tables are gone, but:
+                #  1. the output has 2 blank lines at the top
+                #  2. the underlying dict is different than expected, and tests fail:
+                #     'NIP001  has an incorrect style. Invalid config:',
+                #     '"pyproject.toml".tool.black: Unknown file. See '
+                #     'https://nitpick.rtfd.io/en/latest/plugins.html.']
+
+                # toml_obj = tomlkit.loads(self._string)
+                # if "tool.black" in self._string:
+                #     from tomlkit.items import KeyType, SingleKey
+                #
+                #     black_dict = toml_obj["pyproject.toml"]["tool"]["black"]
+                #     toml_obj["pyproject.toml"].remove("tool")
+                #     toml_obj.remove("pyproject.toml")
+                #     toml_obj.add(SingleKey('"pyproject.toml".tool.black', KeyType.Bare), black_dict)
+                #     result = tomlkit.dumps(toml_obj)
+                #     print(result)
                 self._object = tomlkit.loads(self._string)
             else:
                 self._object = toml.loads(self._string, decoder=InlineTableTomlDecoder(dict))  # type: ignore[call-arg,assignment]
         if self._object is not None:
-            # TODO: tomlkit.dumps() renders comments and I didn't find a way to turn this off,
+            # TODO: fix: tomlkit.dumps() renders comments and I didn't find a way to turn this off,
             #  but comments are being lost when the TOML plugin does dict comparisons.
             if self.use_tomlkit:
+                # TODO: refactor: use only tomlkit and remove uiri/toml
+                #  Removing empty tables on dumps() didn't work.
+                #  Another attempt would be to remove tables when dumping to TOML when setting self._reformatted:
+                #  1. load a dict normally with loads()
+                #  2. clean up TomlDocument and its empty tables recursively, reusing the code with SingleKey above
+                #  3. dump the cleaned TomlDocument
+                #  It looks like some effort. I'll wait for https://github.com/sdispater/tomlkit/issues/166
+                # remove_empty_tables = unflatten(
+                #     flatten(self._object, custom_reducer(SEPARATOR_FLATTEN)), toml_style_splitter
+                # )
                 self._reformatted = tomlkit.dumps(self._object, sort_keys=True)
             else:
                 self._reformatted = toml.dumps(self._object)
@@ -494,7 +560,7 @@ def traverse_toml_tree(document: tomlkit.TOMLDocument, dictionary):
             if key in document:
                 traverse_toml_tree(document[key], value)
             else:
-                document.add(key, value)
+                document[key] = value
         else:
             document[key] = value
 
@@ -502,11 +568,10 @@ def traverse_toml_tree(document: tomlkit.TOMLDocument, dictionary):
 class SensibleYAML(YAML):
     """YAML with sensible defaults but an inefficient dump to string.
 
-    `Output of dump() as a string
-    <https://yaml.readthedocs.io/en/latest/example.html#output-of-dump-as-a-string>`_
+    `Output of dump() as a string <https://yaml.readthedocs.io/en/latest/example.html#output-of-dump-as-a-string>`_.
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.map_indent = 2
         self.sequence_indent = 4
@@ -529,7 +594,6 @@ class YamlDoc(BaseDoc):
 
     updater: SensibleYAML
 
-    @lru_cache()
     def load(self) -> bool:
         """Load a YAML file by its path, a string or a dict."""
         self.updater = SensibleYAML()
@@ -606,7 +670,6 @@ def traverse_yaml_tree(yaml_obj: YamlObject, change: JsonDict):
 class JsonDoc(BaseDoc):
     """JSON configuration format."""
 
-    @lru_cache()
     def load(self) -> bool:
         """Load a JSON file by its path, a string or a dict."""
         if self.path is not None:
