@@ -12,19 +12,28 @@ problems: the code will get executed twice:
 
 Also see (1) from https://click.palletsprojects.com/en/5.x/setuptools/#setuptools-integration
 """
+
+from __future__ import annotations
+
 import logging
 import sys
 from pathlib import Path
-from typing import Optional
 
 import click
+import tomlkit
 from click.exceptions import Exit
 from loguru import logger
 
-from nitpick.blender import TomlDoc
-from nitpick.constants import PROJECT_NAME, TOOL_KEY, TOOL_NITPICK_KEY
+from nitpick import tomlkit_ext
+from nitpick.constants import (
+    CONFIG_KEY_IGNORE_STYLES,
+    CONFIG_KEY_STYLE,
+    CONFIG_TOOL_NITPICK_KEY,
+    PROJECT_NAME,
+    EmojiEnum,
+    Flake8OptionEnum,
+)
 from nitpick.core import Nitpick
-from nitpick.enums import OptionEnum
 from nitpick.exceptions import QuitComplainingError
 from nitpick.generic import relative_to_current_dir
 from nitpick.violations import Reporter
@@ -43,12 +52,13 @@ FILES_ARGUMENT = click.argument("files", nargs=-1)
     help="Path to project root",
 )
 @click.option(
-    f"--{OptionEnum.OFFLINE.name.lower()}",  # pylint: disable=no-member
+    f"--{Flake8OptionEnum.OFFLINE.name.lower()}",  # pylint: disable=no-member
     is_flag=True,
     default=False,
-    help=OptionEnum.OFFLINE.value,
+    help=Flake8OptionEnum.OFFLINE.value,
 )
-def nitpick_cli(project: Path = None, offline=False):  # pylint: disable=unused-argument
+@click.version_option()
+def nitpick_cli(project: Path | None = None, offline=False):  # pylint: disable=unused-argument
     """Enforce the same settings across multiple language-independent projects."""
 
 
@@ -59,7 +69,7 @@ def get_nitpick(context: click.Context) -> Nitpick:
     if context.parent:
         project = context.parent.params["project"]
         offline = context.parent.params["offline"]
-    project_root: Optional[Path] = Path(project) if project else None
+    project_root: Path | None = Path(project) if project else None
     return Nitpick.singleton().init(project_root, offline)
 
 
@@ -133,23 +143,110 @@ def ls(context, files):  # pylint: disable=invalid-name
     if violations:
         for fuss in violations:
             click.echo(fuss.pretty)
-        raise Exit(error_exit_code)  # TODO: test ls with invalid style
+        raise Exit(error_exit_code)  # TODO: test: ls with invalid style
 
-    # TODO: test API .configured_files
+    # TODO: test: configured_files() API
     for file in nit.configured_files(*files):
         click.secho(relative_to_current_dir(file), fg="green" if file.exists() else "red")
 
 
 @nitpick_cli.command()
 @click.pass_context
-def init(context):
-    """Create a [tool.nitpick] section in the configuration file if it doesn't exist already."""
+@click.option(
+    "--fix",
+    "-f",
+    is_flag=True,
+    default=False,
+    help="Autofix the files changed by the command; otherwise, just print what would be done",
+)
+@click.option(
+    "--suggest",
+    "-s",
+    is_flag=True,
+    default=False,
+    help="Suggest styles based on the extension of project files (skipping Git ignored files)",
+)
+@click.option(
+    "--library",
+    "-l",
+    type=click.Path(exists=True, dir_okay=True, file_okay=False, resolve_path=True),
+    help="Library dir to scan for style files (implies --suggest); if not provided, uses the built-in style library",
+)
+@click.argument("style_urls", nargs=-1)
+def init(
+    context,
+    fix: bool,  # pylint: disable=redefined-outer-name
+    suggest: bool,
+    library: str | None,
+    style_urls: list[str],
+) -> None:
+    """Create or update the [tool.nitpick] table in the configuration file."""
+    # If a library is provided, it implies --suggest
+    if library:
+        suggest = True
+
+    if not style_urls and not suggest:
+        click.secho(
+            f"Nothing to do. {EmojiEnum.SLEEPY_FACE.value} Either pass at least one style URL"
+            " or use --suggest to add styles based on the files in the project root"
+            " (you can do both at the same time).",
+            fg="yellow",
+        )
+        return
+
     nit = get_nitpick(context)
     config = nit.project.read_configuration()
 
-    if config.file and PROJECT_NAME in TomlDoc(path=config.file).as_object[TOOL_KEY]:
-        click.secho(f"The config file {config.file.name} already has a [{TOOL_NITPICK_KEY}] section.", fg="yellow")
-        raise Exit(1)
+    # Convert tuple to list, so we can add styles to it
+    style_urls = list(style_urls)
+    if suggest:
+        from nitpick import __version__  # pylint: disable=import-outside-toplevel  # noqa: PLC0415
 
-    nit.project.create_configuration(config)
-    click.secho(f"A [{TOOL_NITPICK_KEY}] section was created in the config file: {config.file.name}", fg="green")
+        # Create the ignored styles array only when suggesting styles
+        if CONFIG_KEY_IGNORE_STYLES not in config.table:
+            config.table.add(CONFIG_KEY_IGNORE_STYLES, config.dont_suggest)
+
+        style_urls.extend(nit.project.suggest_styles(library))
+        tomlkit_ext.update_comment_before(
+            config.table,
+            CONFIG_KEY_STYLE,
+            PROJECT_NAME,
+            f"""
+            (auto-generated by "nitpick init --suggest" {__version__})
+            Styles added to the Nitpick Style Library will be appended to the end of the {CONFIG_KEY_STYLE!r} key.
+            If you don't want a style, move it to the {CONFIG_KEY_IGNORE_STYLES!r} key.
+            """,
+        )
+
+    new_styles = []
+    for style_url in style_urls:
+        if style_url in config.styles or style_url in config.dont_suggest:
+            continue
+        new_styles.append(style_url)
+        config.styles.add_line(style_url, indent="  ")
+    if not new_styles:
+        click.echo(
+            f"All done! {EmojiEnum.STAR_CAKE.value} [{CONFIG_TOOL_NITPICK_KEY}] table left unchanged in {config.file.name!r}"
+        )
+        return
+
+    click.echo("New styles:")
+    for style in new_styles:
+        click.echo(f"- {style}")
+    count = len(new_styles)
+    message = f"{count} style{'s' if count > 1 else ''}"
+
+    if not fix:
+        click.secho(
+            f"Use --fix to append {message} to the [{CONFIG_TOOL_NITPICK_KEY}]"
+            f" table in the config file {config.file.name!r}.",
+            fg="yellow",
+        )
+        return
+
+    config.file.write_text(tomlkit.dumps(config.doc), encoding="UTF-8")
+    click.echo(
+        f"The [{CONFIG_TOOL_NITPICK_KEY}] table was updated in {config.file.name!r}:"
+        f" {message} appended. {EmojiEnum.STAR_CAKE.value}"
+    )
+    raise Exit(1)  # A non-zero exit code is needed when executed as a pre-commit hook
