@@ -1,21 +1,27 @@
 """Base class for file checkers."""
+
+from __future__ import annotations
+
 import abc
 import fnmatch
-from functools import lru_cache
-from pathlib import Path
-from typing import Dict, Iterator, Optional, Set, Type
+from typing import TYPE_CHECKING, ClassVar, Iterator
 
 from autorepr import autotext
 from loguru import logger
-from marshmallow import Schema
 
 from nitpick.blender import BaseDoc, flatten_quotes, search_json
 from nitpick.config import SpecialConfig
-from nitpick.constants import DUNDER_LIST_KEYS
-from nitpick.plugins.info import FileInfo
+from nitpick.constants import CONFIG_DUNDER_LIST_KEYS
 from nitpick.typedefs import JsonDict, mypy_property
 from nitpick.violations import Fuss, Reporter, SharedViolations
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from marshmallow import Schema
+
+    from nitpick.plugins.info import FileInfo
+
 
 class NitpickPlugin(metaclass=abc.ABCMeta):  # pylint: disable=too-many-instance-attributes
     """Base class for Nitpick plugins.
@@ -27,7 +33,7 @@ class NitpickPlugin(metaclass=abc.ABCMeta):  # pylint: disable=too-many-instance
 
     __str__, __unicode__ = autotext("{self.info.path_from_root} ({self.__class__.__name__})")
 
-    filename = ""  # TODO: remove filename attribute after fixing dynamic/fixed schema loading
+    filename = ""  # TODO: refactor: remove filename attribute after fixing dynamic/fixed schema loading
     violation_base_code: int = 0
 
     #: Can this plugin modify its files directly? Are the files fixable?
@@ -35,10 +41,10 @@ class NitpickPlugin(metaclass=abc.ABCMeta):  # pylint: disable=too-many-instance
 
     #: Nested validation field for this file, to be applied in runtime when the validation schema is rebuilt.
     #: Useful when you have a strict configuration for a file type (e.g. :py:class:`nitpick.plugins.json.JsonPlugin`).
-    validation_schema: Optional[Schema] = None
+    validation_schema: Schema | None = None
 
     #: Which ``identify`` tags this :py:class:`nitpick.plugins.base.NitpickPlugin` child recognises.
-    identify_tags: Set[str] = set()
+    identify_tags: ClassVar = set()
 
     skip_empty_suggestion = False
 
@@ -65,7 +71,7 @@ class NitpickPlugin(metaclass=abc.ABCMeta):  # pylint: disable=too-many-instance
 
         # The user can override the default list keys (if any) by setting them on the style file.
         # pylint: disable=assigning-non-slot,no-member
-        spc.list_keys.from_style = self.expected_config.pop(DUNDER_LIST_KEYS, None) or {}
+        spc.list_keys.from_style = self.expected_config.pop(CONFIG_DUNDER_LIST_KEYS, None) or {}
         temp_dict.update(flatten_quotes(spc.list_keys.from_style))
 
         flat_config = flatten_quotes(self.expected_config)
@@ -77,11 +83,13 @@ class NitpickPlugin(metaclass=abc.ABCMeta):  # pylint: disable=too-many-instance
         self.special_config = spc
 
     def predefined_special_config(self) -> SpecialConfig:  # pylint: disable=no-self-use
-        """Create a predefined special configuration for this plugin. Each plugin can override this method."""
+        """Create a predefined special configuration for this plugin.
+
+        Each plugin can override this method.
+        """
         return SpecialConfig()
 
     @mypy_property
-    @lru_cache()
     def nitpick_file_dict(self) -> JsonDict:
         """Nitpick configuration for this file as a TOML dict, taken from the style file."""
         return search_json(self.info.project.nitpick_section, f'files."{self.filename}"', {})
@@ -116,7 +124,7 @@ class NitpickPlugin(metaclass=abc.ABCMeta):  # pylint: disable=too-many-instance
             if fuss:
                 yield fuss
 
-    def post_init(self):
+    def post_init(self):  # noqa: B027
         """Hook for plugin initialization after the instance was created.
 
         The name mimics ``__post_init__()`` on dataclasses, without the magic double underscores:
@@ -134,8 +142,14 @@ class NitpickPlugin(metaclass=abc.ABCMeta):  # pylint: disable=too-many-instance
         else:
             yield self.reporter.make_fuss(SharedViolations.CREATE_FILE)
 
-    def write_file(self, file_exists: bool) -> Optional[Fuss]:  # pylint: disable=unused-argument,no-self-use
-        """Hook to write the new file when autofix mode is on. Should be used by inherited classes."""
+    def write_file(  # pylint: disable=no-self-use
+        self,
+        file_exists: bool,  # pylint: disable=unused-argument # noqa: ARG002
+    ) -> Fuss | None:
+        """Hook to write the new file when autofix mode is on.
+
+        Should be used by inherited classes.
+        """
         return None
 
     @abc.abstractmethod
@@ -147,7 +161,7 @@ class NitpickPlugin(metaclass=abc.ABCMeta):  # pylint: disable=too-many-instance
     def initial_contents(self) -> str:
         """Suggested initial content when the file doesn't exist."""
 
-    def write_initial_contents(self, doc_class: Type[BaseDoc], expected_dict: Dict = None) -> str:
+    def write_initial_contents(self, doc_class: type[BaseDoc], expected_dict: dict | None = None) -> str:
         """Helper to write initial contents based on a format."""
         if not expected_dict:
             expected_dict = self.expected_config
