@@ -1,12 +1,18 @@
 """Info needed by the plugins."""
+
+from __future__ import annotations
+
 from dataclasses import dataclass, field
-from typing import Set
+from pathlib import Path
+from typing import TYPE_CHECKING
 
 from identify import identify
 
 from nitpick.constants import DOT
 from nitpick.exceptions import Deprecation
-from nitpick.project import Project
+
+if TYPE_CHECKING:
+    from nitpick.core import Project
 
 
 @dataclass
@@ -15,14 +21,20 @@ class FileInfo:
 
     project: Project
     path_from_root: str
-    tags: Set[str] = field(default_factory=set)
+    tags: set[str] = field(default_factory=set)
 
     @classmethod
-    def create(cls, project: Project, path_from_root: str) -> "FileInfo":
+    def create(cls, project: Project, path_from_root: str) -> FileInfo:
         """Clean the file name and get its tags."""
         if Deprecation.pre_commit_without_dash(path_from_root):
             clean_path = DOT + path_from_root
         else:
             clean_path = DOT + path_from_root[1:] if path_from_root.startswith("-") else path_from_root
-        tags = set(identify.tags_from_filename(clean_path))
+
+        # When we run identify on the actual file we get better tags
+        if Path(clean_path).exists():
+            tags = set(identify.tags_from_path(clean_path))
+        else:
+            tags = set(identify.tags_from_filename(clean_path))
+
         return cls(project, clean_path, tags)
