@@ -1,16 +1,21 @@
 """INI files."""
+
+from __future__ import annotations
+
 from configparser import ConfigParser, DuplicateOptionError, Error, MissingSectionHeaderError, ParsingError
 from io import StringIO
-from typing import Any, Dict, Iterator, List, Optional, Set, Tuple, Type
+from typing import TYPE_CHECKING, Any, ClassVar, Iterator
 
 import dictdiffer
 from configupdater import ConfigUpdater, Space
 
 from nitpick.plugins import hookimpl
 from nitpick.plugins.base import NitpickPlugin
-from nitpick.plugins.info import FileInfo
 from nitpick.violations import Fuss, ViolationEnum
 
+if TYPE_CHECKING:
+    from nitpick.plugins.info import FileInfo
+
 COMMA_SEPARATED_VALUES = "comma_separated_values"
 SECTION_SEPARATOR = "."
 TOP_SECTION = "__TEMPORARY_TOP_SECTION__"
@@ -37,17 +42,18 @@ class IniPlugin(NitpickPlugin):
     - `setup.cfg <https://docs.python.org/3/distutils/configfile.html>`_
     - `.editorconfig <https://editorconfig.org/>`_
     - `tox.ini <https://github.com/tox-dev/tox>`_
-    - `.pylintrc <https://pylint.readthedocs.io/en/latest/user_guide/run.html#command-line-options>`_
+    - `.pylintrc <https://pylint.readthedocs.io/en/latest/user_guide/usage/run.html#command-line-options>`_
 
-    Style examples enforcing values on INI files: :ref:`flake8 configuration <example-flake8>`.
+    Style examples enforcing values on INI files: :gitref:`flake8 configuration
+    <src/nitpick/resources/python/flake8.toml>`.
     """
 
     fixable = True
-    identify_tags = {"ini", "editorconfig"}
+    identify_tags: ClassVar = {"ini", "editorconfig"}
     violation_base_code = 320
 
     updater: ConfigUpdater
-    comma_separated_values: Set[str]
+    comma_separated_values: set[str]
 
     def post_init(self):
         """Post initialization after the instance was created."""
@@ -59,7 +65,7 @@ class IniPlugin(NitpickPlugin):
         if all(isinstance(v, dict) for v in self.expected_config.values()):
             return
 
-        new_config = dict({TOP_SECTION: {}})
+        new_config = {TOP_SECTION: {}}
         for key, value in self.expected_config.items():
             if isinstance(value, dict):
                 new_config[key] = value
@@ -73,7 +79,7 @@ class IniPlugin(NitpickPlugin):
         return "editorconfig" in self.info.tags
 
     @property
-    def current_sections(self) -> Set[str]:
+    def current_sections(self) -> set[str]:
         """Current sections of the .ini file, including updated sections."""
         return set(self.updater.sections())
 
@@ -83,16 +89,16 @@ class IniPlugin(NitpickPlugin):
         return self.get_missing_output()
 
     @property
-    def expected_sections(self) -> Set[str]:
+    def expected_sections(self) -> set[str]:
         """Expected sections (from the style config)."""
         return set(self.expected_config.keys())
 
     @property
-    def missing_sections(self) -> Set[str]:
+    def missing_sections(self) -> set[str]:
         """Missing sections."""
         return self.expected_sections - self.current_sections
 
-    def write_file(self, file_exists: bool) -> Optional[Fuss]:
+    def write_file(self, file_exists: bool) -> Fuss | None:
         """Write the new file."""
         try:
             if self.needs_top_section:
@@ -120,7 +126,7 @@ class IniPlugin(NitpickPlugin):
 
         parser = ConfigParser()
         for section in sorted(missing, key=lambda s: "0" if s == TOP_SECTION else f"1{s}"):
-            expected_config: Dict = self.expected_config[section]
+            expected_config: dict = self.expected_config[section]
             if self.autofix:
                 if self.updater.last_block:
                     self.updater.last_block.add_after.space(1)
@@ -130,7 +136,7 @@ class IniPlugin(NitpickPlugin):
             parser[section] = expected_config
         return self.contents_without_top_section(self.get_example_cfg(parser))
 
-    # TODO: convert the contents to dict (with IniConfig().sections?) and mimic other plugins doing dict diffs
+    # TODO: refactor: convert the contents to dict (with IniConfig().sections?) and mimic other plugins doing dict diffs
     def enforce_rules(self) -> Iterator[Fuss]:
         """Enforce rules on missing sections and missing key/value pairs in an INI file."""
         try:
@@ -154,7 +160,7 @@ class IniPlugin(NitpickPlugin):
 
     def _read_file(self) -> Iterator[Fuss]:
         """Read the .ini file or special files like .editorconfig."""
-        parsing_err: Optional[Error] = None
+        parsing_err: Error | None = None
         try:
             self.updater.read(str(self.file_path))
         except MissingSectionHeaderError as err:
@@ -186,7 +192,7 @@ class IniPlugin(NitpickPlugin):
         """Enforce rules for a section."""
         expected_dict = self.expected_config[section]
         actual_dict = {k: v.value for k, v in self.updater[section].items()}
-        # TODO: add a class Ini(BaseDoc) and move this dictdiffer code there
+        # TODO: refactor: add a class Ini(BaseDoc) and move this dictdiffer code there
         for diff_type, key, values in dictdiffer.diff(actual_dict, expected_dict):
             if diff_type == dictdiffer.CHANGE:
                 if f"{section}.{key}" in self.comma_separated_values:
@@ -197,7 +203,10 @@ class IniPlugin(NitpickPlugin):
                 yield from self.show_missing_keys(section, values)
 
     def enforce_comma_separated_values(self, section, key, raw_actual: Any, raw_expected: Any) -> Iterator[Fuss]:
-        """Enforce sections and keys with comma-separated values. The values might contain spaces."""
+        """Enforce sections and keys with comma-separated values.
+
+        The values might contain spaces.
+        """
         actual_set = {s.strip() for s in raw_actual.split(",")}
         expected_set = {s.strip() for s in raw_expected.split(",")}
         missing = expected_set - actual_set
@@ -210,7 +219,7 @@ class IniPlugin(NitpickPlugin):
             self.updater[section][key].value += value_to_append
             self.dirty = True
         section_header = "" if section == TOP_SECTION else f"[{section}]\n"
-        # TODO: proper testing of top section with separated values in https://github.com/andreoliwa/nitpick/issues/271
+        # TODO: test: top section with separated values in https://github.com/andreoliwa/nitpick/issues/271
         yield self.reporter.make_fuss(
             Violations.MISSING_VALUES_IN_LIST,
             f"{section_header}{key} = (...){value_to_append}",
@@ -251,7 +260,7 @@ class IniPlugin(NitpickPlugin):
                 fixed=self.autofix,
             )
 
-    def show_missing_keys(self, section: str, values: List[Tuple[str, Any]]) -> Iterator[Fuss]:
+    def show_missing_keys(self, section: str, values: list[tuple[str, Any]]) -> Iterator[Fuss]:
         """Show the keys that are not present in a section."""
         parser = ConfigParser()
         missing_dict = dict(values)
@@ -266,7 +275,7 @@ class IniPlugin(NitpickPlugin):
         else:
             yield self.reporter.make_fuss(Violations.MISSING_OPTION, output, self.autofix, section=section)
 
-    def add_options_before_space(self, section: str, options: Dict) -> None:
+    def add_options_before_space(self, section: str, options: dict) -> None:
         """Add new options before a blank line in the end of the section."""
         if not self.autofix:
             return
@@ -287,18 +296,17 @@ class IniPlugin(NitpickPlugin):
         """Print an example of a config parser in a string instead of a file."""
         string_stream = StringIO()
         parser.write(string_stream)
-        output = string_stream.getvalue().strip()
-        return output
+        return string_stream.getvalue().strip()
 
 
 @hookimpl
-def plugin_class() -> Type["NitpickPlugin"]:
+def plugin_class() -> type[NitpickPlugin]:
     """Handle INI files."""
     return IniPlugin
 
 
 @hookimpl
-def can_handle(info: FileInfo) -> Optional[Type["NitpickPlugin"]]:
+def can_handle(info: FileInfo) -> type[NitpickPlugin] | None:
     """Handle INI files."""
     if IniPlugin.identify_tags & info.tags:
         return IniPlugin
