@@ -1,5 +1,8 @@
 """Text files."""
-from typing import Iterator, Optional, Type
+
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, ClassVar, Iterator
 
 from marshmallow import Schema
 from marshmallow.orderedset import OrderedSet
@@ -7,10 +10,12 @@ from marshmallow.orderedset import OrderedSet
 from nitpick import fields
 from nitpick.plugins import hookimpl
 from nitpick.plugins.base import NitpickPlugin
-from nitpick.plugins.info import FileInfo
 from nitpick.schemas import help_message
 from nitpick.violations import Fuss, ViolationEnum
 
+if TYPE_CHECKING:
+    from nitpick.plugins.info import FileInfo
+
 TEXT_FILE_RTFD_PAGE = "plugins.html#text-files"
 KEY_CONTAINS = "contains"
 
@@ -18,14 +23,14 @@ KEY_CONTAINS = "contains"
 class TextItemSchema(Schema):
     """Validation schema for the object inside ``contains``."""
 
-    error_messages = {"unknown": help_message("Unknown configuration", TEXT_FILE_RTFD_PAGE)}
+    error_messages = {"unknown": help_message("Unknown configuration", TEXT_FILE_RTFD_PAGE)}  # noqa: RUF012
     line = fields.NonEmptyString()
 
 
 class TextSchema(Schema):
     """Validation schema for the text file TOML configuration."""
 
-    error_messages = {"unknown": help_message("Unknown configuration", TEXT_FILE_RTFD_PAGE)}
+    error_messages = {"unknown": help_message("Unknown configuration", TEXT_FILE_RTFD_PAGE)}  # noqa: RUF012
     contains = fields.List(fields.Nested(TextItemSchema))
 
 
@@ -49,11 +54,11 @@ class TextPlugin(NitpickPlugin):
         line = "def"
     """
 
-    identify_tags = {"text"}
+    identify_tags: ClassVar = {"text"}
     validation_schema = TextSchema
 
     #: All other files are also text files, and they already have a suggested content message
-    # TODO: this is a hack to avoid rethinking the whole schema validation now (this will have to be done some day)
+    # TODO: refactor: rethink the whole schema validation and remove this attribute
     skip_empty_suggestion = True
 
     violation_base_code = 350
@@ -76,13 +81,13 @@ class TextPlugin(NitpickPlugin):
 
 
 @hookimpl
-def plugin_class() -> Type["NitpickPlugin"]:
+def plugin_class() -> type[NitpickPlugin]:
     """Handle text files."""
     return TextPlugin
 
 
 @hookimpl
-def can_handle(info: FileInfo) -> Optional[Type["NitpickPlugin"]]:
+def can_handle(info: FileInfo) -> type[NitpickPlugin] | None:
     """Handle text files."""
     if TextPlugin.identify_tags & info.tags:
         return TextPlugin
