@@ -1,16 +1,22 @@
 """TOML files."""
+
+from __future__ import annotations
+
 from itertools import chain
-from typing import Iterator, Optional, Type
+from typing import TYPE_CHECKING, ClassVar, Iterator, cast
 
 from tomlkit import dumps, parse
-from tomlkit.toml_document import TOMLDocument
 
-from nitpick.blender import BaseDoc, Comparison, TomlDoc, traverse_toml_tree
+from nitpick.blender import Comparison, TomlDoc, traverse_toml_tree
 from nitpick.plugins import hookimpl
 from nitpick.plugins.base import NitpickPlugin
-from nitpick.plugins.info import FileInfo
 from nitpick.violations import Fuss, SharedViolations, ViolationEnum
 
+if TYPE_CHECKING:
+    from tomlkit.toml_document import TOMLDocument
+
+    from nitpick.plugins.info import FileInfo
+
 
 class TomlPlugin(NitpickPlugin):
     """Enforce configurations and autofix TOML files.
@@ -20,11 +26,11 @@ class TomlPlugin(NitpickPlugin):
     See also `the [tool.poetry] section of the pyproject.toml file
     <https://github.com/python-poetry/poetry/blob/master/docs/pyproject.md>`_.
 
-    Style example: :ref:`Python 3.8 version constraint <example-python-3-8>`.
-    There are :ref:`many other examples here <examples>`.
+    Style example: :gitref:`Python 3.8 version constraint <src/nitpick/resources/python/38.toml>`.
+    There are :ref:`many other examples here <library>`.
     """
 
-    identify_tags = {"toml"}
+    identify_tags: ClassVar = {"toml"}
     violation_base_code = 310
     fixable = True
 
@@ -37,20 +43,34 @@ class TomlPlugin(NitpickPlugin):
 
         document = parse(toml_doc.as_string) if self.autofix else None
         yield from chain(
-            self.report(SharedViolations.DIFFERENT_VALUES, document, comparison.diff),
-            self.report(SharedViolations.MISSING_VALUES, document, comparison.missing),
+            self.report(SharedViolations.DIFFERENT_VALUES, document, cast("TomlDoc", comparison.diff)),
+            self.report(
+                SharedViolations.MISSING_VALUES,
+                document,
+                cast("TomlDoc", comparison.missing),
+                cast("TomlDoc", comparison.replace),
+            ),
         )
         if self.autofix and self.dirty:
             self.file_path.write_text(dumps(document))
 
-    def report(self, violation: ViolationEnum, document: Optional[TOMLDocument], change: Optional[BaseDoc]):
+    def report(
+        self,
+        violation: ViolationEnum,
+        document: TOMLDocument | None,
+        change: TomlDoc | None,
+        replacement: TomlDoc | None = None,
+    ):
         """Report a violation while optionally modifying the TOML document."""
-        if not change:
+        if not (change or replacement):
             return
-        if document:
-            traverse_toml_tree(document, change.as_object)
+        if self.autofix:
+            real_change = cast("TomlDoc", replacement or change)
+            traverse_toml_tree(document, real_change.as_object)
             self.dirty = True
-        yield self.reporter.make_fuss(violation, change.reformatted.strip(), prefix="", fixed=self.autofix)
+
+        to_display = cast("TomlDoc", change or replacement)
+        yield self.reporter.make_fuss(violation, to_display.reformatted.strip(), prefix="", fixed=self.autofix)
 
     @property
     def initial_contents(self) -> str:
@@ -59,13 +79,13 @@ class TomlPlugin(NitpickPlugin):
 
 
 @hookimpl
-def plugin_class() -> Type["NitpickPlugin"]:
+def plugin_class() -> type[NitpickPlugin]:
     """Handle TOML files."""
     return TomlPlugin
 
 
 @hookimpl
-def can_handle(info: FileInfo) -> Optional[Type["NitpickPlugin"]]:
+def can_handle(info: FileInfo) -> type[NitpickPlugin] | None:
     """Handle TOML files."""
     if TomlPlugin.identify_tags & info.tags:
         return TomlPlugin
